# Diagram Templates
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/diagram-templates#overview)
  * [Key Features](https://help.sap.com/docs/leanix/ea/diagram-templates#key-features)
  * [Diagram Templates versus Standard Diagrams](https://help.sap.com/docs/leanix/ea/diagram-templates#diagram-templates-versus-standard-diagrams)
  * [Preset Diagram Templates](https://help.sap.com/docs/leanix/ea/diagram-templates#preset-diagram-templates)
  * [Limitations](https://help.sap.com/docs/leanix/ea/diagram-templates#limitations)
  * [Getting Started](https://help.sap.com/docs/leanix/ea/diagram-templates#getting-started)
  * [Managing Diagram Templates](https://help.sap.com/docs/leanix/ea/diagram-templates#managing-diagram-templates)
  * [Diagram Template Permissions](https://help.sap.com/docs/leanix/ea/diagram-templates#diagram-template-permissions)
  * [Best Practices](https://help.sap.com/docs/leanix/ea/diagram-templates#best-practices)


Diagram templates provide reusable, standardized rules for visualizing live inventory data, enabling dynamic exploration and consistent documentation of your landscape. Use them to efficiently create, manage, and share up-to-date diagrams for analysis, stakeholder communication, and audits.
